@@ -69,7 +69,7 @@ public:
 	QString host;
 	int port;
 	QString user, pass;
-	QString url;
+	QUrl url;
 	bool use_proxy;
 
 	QByteArray out;
@@ -128,15 +128,17 @@ void HttpPoll::setAuth(const QString &user, const QString &pass)
 	d->pass = pass;
 }
 
-void HttpPoll::connectToUrl(const QString &url)
+void HttpPoll::connectToUrl(const QUrl &url)
 {
 	connectToHost("", 0, url);
 }
 
-void HttpPoll::connectToHost(const QString &proxyHost, int proxyPort, const QString &url)
+void HttpPoll::connectToHost(const QString &proxyHost, int proxyPort, const QUrl &url)
 {
 	reset(true);
 
+	bool useSsl = false;
+	d->port = 80;
 	// using proxy?
 	if(!proxyHost.isEmpty()) {
 		d->host = proxyHost;
@@ -145,13 +147,18 @@ void HttpPoll::connectToHost(const QString &proxyHost, int proxyPort, const QStr
 		d->use_proxy = true;
 	}
 	else {
-		QUrl u = url;
-		d->host = u.host();
-		if(u.port() != -1)
-			d->port = u.port();
-		else
-			d->port = 80;
-		d->url = u.path() + "?" + u.encodedQuery();
+		d->host = url.host();
+		if(url.port() != -1)
+			d->port = url.port();
+		else if (url.scheme() == "https") {
+			d->port = 443;
+			useSsl = true;
+		}
+#if QT_VERSION < 0x050000
+		d->url = url.path() + "?" + url.encodedQuery();
+#else
+		d->url.setUrl(url.path() + "?" + url.query(QUrl::FullyEncoded), QUrl::StrictMode);
+#endif
 		d->use_proxy = false;
 	}
 
@@ -172,6 +179,7 @@ void HttpPoll::connectToHost(const QString &proxyHost, int proxyPort, const QStr
 		return;
 
 	d->state = 1;
+	d->http.setUseSsl(useSsl);
 	d->http.setAuth(d->user, d->pass);
 	d->http.post(d->host, d->port, d->url, makePacket("0", key, "", QByteArray()), d->use_proxy);
 }
@@ -238,7 +246,7 @@ void HttpPoll::http_result()
 	int n = cookie.indexOf("ID=");
 	if(n == -1) {
 		reset();
-		error(ErrRead);
+		setError(ErrRead);
 		return;
 	}
 	n += 3;
@@ -258,7 +266,7 @@ void HttpPoll::http_result()
 		}
 		else {
 			reset();
-			error(ErrRead);
+			setError(ErrRead);
 			return;
 		}
 	}
@@ -315,17 +323,17 @@ void HttpPoll::http_error(int x)
 {
 	reset();
 	if(x == HttpProxyPost::ErrConnectionRefused)
-		error(ErrConnectionRefused);
+		setError(ErrConnectionRefused);
 	else if(x == HttpProxyPost::ErrHostNotFound)
-		error(ErrHostNotFound);
+		setError(ErrHostNotFound);
 	else if(x == HttpProxyPost::ErrSocket)
-		error(ErrRead);
+		setError(ErrRead);
 	else if(x == HttpProxyPost::ErrProxyConnect)
-		error(ErrProxyConnect);
+		setError(ErrProxyConnect);
 	else if(x == HttpProxyPost::ErrProxyNeg)
-		error(ErrProxyNeg);
+		setError(ErrProxyNeg);
 	else if(x == HttpProxyPost::ErrProxyAuth)
-		error(ErrProxyAuth);
+		setError(ErrProxyAuth);
 }
 
 int HttpPoll::tryWrite()
@@ -434,18 +442,27 @@ class HttpProxyPost::Private
 {
 public:
 	Private(HttpProxyPost *_q) :
-		sock(_q)
+		sock(_q),
+		tls(0)
 	{
 	}
 
+	~Private()
+	{
+		delete tls;
+	}
+
 	BSocket sock;
+	QHostAddress lastAddress;
 	QByteArray postdata, recvBuf, body;
-	QString url;
+	QUrl url;
 	QString user, pass;
 	bool inHeader;
 	QStringList headerLines;
 	bool asProxy;
+	bool useSsl;
 	QString host;
+	QCA::TLS *tls;
 };
 
 HttpProxyPost::HttpProxyPost(QObject *parent)
@@ -465,6 +482,11 @@ HttpProxyPost::~HttpProxyPost()
 	delete d;
 }
 
+void HttpProxyPost::setUseSsl(bool state)
+{
+	d->useSsl = state;
+}
+
 void HttpProxyPost::reset(bool clear)
 {
 	if(d->sock.state() != BSocket::Idle)
@@ -485,7 +507,7 @@ bool HttpProxyPost::isActive() const
 	return (d->sock.state() == BSocket::Idle ? false: true);
 }
 
-void HttpProxyPost::post(const QString &proxyHost, int proxyPort, const QString &url, const QByteArray &data, bool asProxy)
+void HttpProxyPost::post(const QString &proxyHost, int proxyPort, const QUrl &url, const QByteArray &data, bool asProxy)
 {
 	reset(true);
 
@@ -501,7 +523,13 @@ void HttpProxyPost::post(const QString &proxyHost, int proxyPort, const QString
 	else
 		fprintf(stderr, ", auth {%s,%s}\n", d->user.latin1(), d->pass.latin1());
 #endif
-	d->sock.connectToHost(proxyHost, proxyPort);
+	if (d->sock.state() != QAbstractSocket::ConnectingState) { // in case of http/1.1 it may be connected
+		if (d->lastAddress.isNull()) {
+			d->sock.connectToHost(proxyHost, proxyPort);
+		} else {
+			d->sock.connectToHost(d->lastAddress, proxyPort);
+		}
+	}
 }
 
 void HttpProxyPost::stop()
@@ -533,34 +561,51 @@ void HttpProxyPost::sock_connected()
 #ifdef PROX_DEBUG
 	fprintf(stderr, "HttpProxyPost: Connected\n");
 #endif
+	if(d->useSsl) {
+		d->tls = new QCA::TLS(this);
+		connect(d->tls, SIGNAL(readyRead()), SLOT(tls_readyRead()));
+		connect(d->tls, SIGNAL(readyReadOutgoing()), SLOT(tls_readyReadOutgoing()));
+		connect(d->tls, SIGNAL(error()), SLOT(tls_error()));
+		d->tls->startClient();
+	}
+
+	d->lastAddress = d->sock.peerAddress();
 	d->inHeader = true;
 	d->headerLines.clear();
 
 	QUrl u = d->url;
 
 	// connected, now send the request
-	QString s;
-	s += QString("POST ") + d->url + " HTTP/1.0\r\n";
+	QByteArray s;
+	s += QByteArray("POST ") + d->url.toEncoded() + " HTTP/1.1\r\n";
 	if(d->asProxy) {
 		if(!d->user.isEmpty()) {
-			QString str = d->user + ':' + d->pass;
-			s += QString("Proxy-Authorization: Basic ") + QCA::Base64().encodeString(str) + "\r\n";
+			QByteArray str = d->user.toUtf8() + ':' + d->pass.toUtf8();
+			s += QByteArray("Proxy-Authorization: Basic ") + str.toBase64() + "\r\n";
 		}
 		s += "Pragma: no-cache\r\n";
-		s += QString("Host: ") + u.host() + "\r\n";
+		s += QByteArray("Host: ") + u.host() + "\r\n";
 	}
 	else {
-		s += QString("Host: ") + d->host + "\r\n";
+		s += QByteArray("Host: ") + d->host + "\r\n";
 	}
 	s += "Content-Type: application/x-www-form-urlencoded\r\n";
-	s += QString("Content-Length: ") + QString::number(d->postdata.size()) + "\r\n";
+	s += QByteArray("Content-Length: ") + QByteArray::number(d->postdata.size()) + "\r\n";
 	s += "\r\n";
 
-	// write request
-	d->sock.write(s.toUtf8());
+	if(d->useSsl) {
+		// write request
+		d->tls->write(s);
 
-	// write postdata
-	d->sock.write(d->postdata);
+		// write postdata
+		d->tls->write(d->postdata);
+	} else {
+		// write request
+		d->sock.write(s);
+
+		// write postdata
+		d->sock.write(d->postdata);
+	}
 }
 
 void HttpProxyPost::sock_connectionClosed()
@@ -570,10 +615,39 @@ void HttpProxyPost::sock_connectionClosed()
 	result();
 }
 
+void HttpProxyPost::tls_readyRead()
+{
+	//printf("tls_readyRead\n");
+	processData(d->tls->read());
+}
+
+void HttpProxyPost::tls_readyReadOutgoing()
+{
+	//printf("tls_readyReadOutgoing\n");
+	d->sock.write(d->tls->readOutgoing());
+}
+
+void HttpProxyPost::tls_error()
+{
+#ifdef PROX_DEBUG
+	fprintf(stderr, "HttpProxyGetStream: ssl error: %d\n", d->tls->errorCode());
+#endif
+	reset(true);
+	error(ErrConnectionRefused); // FIXME: bogus error
+}
+
 void HttpProxyPost::sock_readyRead()
 {
-	QByteArray block = d->sock.read();
-	ByteStream::appendArray(&d->recvBuf, block);
+	QByteArray block = d->sock.readAll();
+	if(d->useSsl)
+		d->tls->writeIncoming(block);
+	else
+		processData(block);
+}
+
+void HttpProxyPost::processData(const QByteArray &block)
+{
+	d->recvBuf += block;
 
 	if(d->inHeader) {
 		// grab available lines
@@ -828,7 +902,7 @@ void HttpProxyGetStream::sock_connectionClosed()
 
 void HttpProxyGetStream::sock_readyRead()
 {
-	QByteArray block = d->sock.read();
+	QByteArray block = d->sock.readAll();
 
 	if(d->use_ssl)
 		d->tls->writeIncoming(block);
@@ -844,7 +918,7 @@ void HttpProxyGetStream::processData(const QByteArray &block)
 		return;
 	}
 
-	ByteStream::appendArray(&d->recvBuf, block);
+	d->recvBuf += block;
 
 	if(d->inHeader) {
 		// grab available lines
