@@ -19,7 +19,6 @@
  */
 
 #include <QMap>
-#include <QApplication>
 #include <QList>
 
 #include "im.h"
@@ -2240,27 +2239,27 @@ void Status::setType(Status::Type _type)
 
 Status::Type Status::txt2type(const QString& stat)
 {
-	if (stat == "offline")
-		return XMPP::Status::Offline;
-	else if (stat == "online")
-		return XMPP::Status::Online;
-	else if (stat == "away")
-		return XMPP::Status::Away;
-	else if (stat == "xa")
-		return XMPP::Status::XA;
-	else if (stat == "dnd")
-		return XMPP::Status::DND;
-	else if (stat == "invisible")
-		return XMPP::Status::Invisible;
-	else if (stat == "chat")
-		return XMPP::Status::FFC;
-	else
-		return XMPP::Status::Away;
+      if (stat == "offline")
+              return XMPP::Status::Offline;
+      else if (stat == "online")
+              return XMPP::Status::Online;
+      else if (stat == "away")
+              return XMPP::Status::Away;
+      else if (stat == "xa")
+              return XMPP::Status::XA;
+      else if (stat == "dnd")
+              return XMPP::Status::DND;
+      else if (stat == "invisible")
+              return XMPP::Status::Invisible;
+      else if (stat == "chat")
+              return XMPP::Status::FFC;
+      else
+              return XMPP::Status::Away;
 }
 
 void Status::setType(QString stat)
 {
-	setType(txt2type(stat));
+      setType(txt2type(stat));
 }
 
 void Status::setShow(const QString & _show)
