@@ -33,6 +33,8 @@
 #include "privacydlg.h"
 #include "pgpkeydlg.h"
 #include "psicontactlist.h"
+#include "iconaction.h"
+#include "actionlineedit.h"
 
 AccountModifyDlg::AccountModifyDlg(PsiCon *_psi, QWidget *parent)
 :QDialog(parent)
@@ -48,7 +50,7 @@ AccountModifyDlg::AccountModifyDlg(PsiCon *_psi, QWidget *parent)
 AccountModifyDlg::AccountModifyDlg(PsiAccount *_pa, QWidget *parent)
 :QDialog(parent)
 {
-  	setupUi(this);
+	setupUi(this);
 	setModal(false);
 	setAttribute(Qt::WA_DeleteOnClose);
 	pa = _pa;
@@ -57,14 +59,14 @@ AccountModifyDlg::AccountModifyDlg(PsiAccount *_pa, QWidget *parent)
 	init();
 }
 
-void AccountModifyDlg::init() 
+void AccountModifyDlg::init()
 {
 	//connect(pa->psi(), SIGNAL(pgpToggled(bool)), SLOT(pgpToggled(bool)));
 	if (pa)
 		pa->dialogRegister(this);
 
 	setWindowTitle(CAP(windowTitle()));
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
 	setWindowIcon(IconsetFactory::icon("psi/account").icon());
 #endif
 #if QT_VERSION >= 0x040500
@@ -108,12 +110,12 @@ void AccountModifyDlg::init()
 	cb_ssl->addItem(tr("Legacy SSL"), UserAccount::SSL_Legacy);
 	cb_ssl->setCurrentIndex(cb_ssl->findData(acc.ssl));
 	connect(cb_ssl, SIGNAL(activated(int)), SLOT(sslActivated(int)));
-	
+
 	cb_plain->addItem(tr("Always"),ClientStream::AllowPlain);
 	cb_plain->addItem(tr("Over encrypted connection"), ClientStream::AllowPlainOverTLS);
 	cb_plain->addItem(tr("Never"), ClientStream::NoAllowPlain);
 	cb_plain->setCurrentIndex(cb_plain->findData(acc.allow_plain));
-	
+
 	if (acc.opt_pass)
 		le_pass->setText(acc.pass);
 
@@ -121,7 +123,6 @@ void AccountModifyDlg::init()
 	le_host->setText(acc.host);
 	le_port->setText(QString::number(acc.port));
 	ck_req_mutual->setChecked(acc.req_mutual_auth);
-	ck_legacy_ssl_probe->setChecked(acc.legacy_ssl_probe);
 
 	connect(cb_resource, SIGNAL(currentIndexChanged(int)), SLOT(resourceCbChanged(int)));
 	connect(cb_priority, SIGNAL(currentIndexChanged(int)), SLOT(priorityCbChanged(int)));
@@ -143,7 +144,7 @@ void AccountModifyDlg::init()
 	ck_custom_auth->setChecked(acc.customAuth);
 	le_authid->setText(acc.authid);
 	le_realm->setText(acc.realm);
-		
+
 	ck_compress->setChecked(acc.opt_compress);
 	ck_auto->setChecked(acc.opt_auto);
 	ck_reconn->setChecked(acc.opt_reconn);
@@ -153,8 +154,21 @@ void AccountModifyDlg::init()
 	ck_keepAlive->setChecked(acc.opt_keepAlive);
 	ck_ibbOnly->setChecked(acc.ibbOnly);
 	le_dtProxy->setText(acc.dtProxy.full());
-	le_stunHost->setText(acc.stunHost);
-	le_stunPort->setText(QString::number(acc.stunPort));
+
+	ActionLineEdit *ale_delStunHost = new ActionLineEdit(cb_stunHost);
+	cb_stunHost->setLineEdit(ale_delStunHost);
+	IconAction *ia_delStunHost = new IconAction(tr("Delete current host from the list"), this, "psi/remove");
+	connect(ia_delStunHost, SIGNAL(triggered()), SLOT(removeStunHost()));
+	ale_delStunHost->addAction(ia_delStunHost);
+
+	cb_stunHost->addItem(tr("<don't use>"));
+	cb_stunHost->addItems(acc.stunHosts);
+	if (acc.stunHost.isEmpty()) {
+		cb_stunHost->setCurrentIndex(0);
+	}
+	else {
+		cb_stunHost->setCurrentIndex(cb_stunHost->findText(acc.stunHost));
+	}
 	le_stunUser->setText(acc.stunUser);
 	le_stunPass->setText(acc.stunPass);
 	autoconnectCksChanged();
@@ -211,7 +225,7 @@ void AccountModifyDlg::init()
 	cb_plain->setWhatsThis(
 		tr("Normally, Psi logs in using the <i>digest</i> authentication "
 		"method.  Check this box to force a plain text login "
-		"to the Jabber server. Use this option only if you have "
+		"to the XMPP server. Use this option only if you have "
 		"problems connecting with the normal login procedure, as it "
 		"makes your connection potentially vulnerable to "
 		"attacks."));
@@ -238,36 +252,36 @@ void AccountModifyDlg::init()
 		"up all the time."));
 	cb_ssl->setWhatsThis(
 		tr("Check this option to use an encrypted SSL connection to "
-		"the Jabber server.  You may use this option if your "
-		"server supports it and if you have the necessary QCA-OpenSSL "
+		"the XMPP server.  You may use this option if your "
+		"server supports it and if you have the necessary qca-ossl "
 		"plugin installed.  For more information, check the "
 		"Psi homepage."));
 	ck_compress->setWhatsThis(
 		tr("Check this option to use a compressed connection to "
-		"the Jabber server, if the server supports it."));
+		"the XMPP server, if the server supports it."));
 	ck_host->setWhatsThis(
-		tr("Use this option for manual configuration of your Jabber host "
+		tr("Use this option for manual configuration of your XMPP host "
 		"if it is not the same as the host you are connecting to.  This option is mostly useful "
 		"if you have some sort of proxy route on your "
 		"local machine (i.e. you connect to localhost), but your "
 		"account is registered on an external server."));
 	le_resource->setWhatsThis(
-		tr("You can have multiple clients connected to the Jabber server "
+		tr("You can have multiple clients connected to the XMPP server "
 		"with your single account.  Each login is distinguished by a \"resource\" "
 		"name, which you can specify in this field."));
 	ck_custom_auth->setWhatsThis(
 		tr("This option sets the user (and realm) you want to "
-			"authenticate as. This overrides the Jabber ID you are logging in "
+			"authenticate as. This overrides the XMPP address you are logging in "
 			"as."));
 	sb_priority->setWhatsThis(
-		tr("<p>You can have multiple clients connected to the Jabber "
+		tr("<p>You can have multiple clients connected to the XMPP "
 		"server with your single account.  In such a situation, "
 		"the client with the highest priority (that is specified in "
 		"this field) will be the one that will receive "
 		"all incoming events.</p>"
 		"<p>For example, if you have a permanent connection "
 		"to the Internet at your work location, and have a dial-up at home, "
-		"you can have your Jabber client permanently running at work "
+		"you can have your XMPP client permanently running at work "
 		"with a low priority, and you can still use the same account "
 		"from home, using a client with higher priority to "
 		"temporary \"disable\" the lower priority client at work.</p>"));
@@ -277,19 +291,19 @@ void AccountModifyDlg::init()
 		le_name->hide();
 		lb_name->hide();
 	}
-	
+
 	if (!PsiOptions::instance()->getOption("options.account.domain").toString().isEmpty()) {
 		lb_example->hide();
 		lb_jid->setText(tr("Username:"));
 	}
-	
+
 	if (!PsiOptions::instance()->getOption("options.pgp.enable").toBool()) {
 		gb_pgp->hide();
 	}
-	
-	if (!PsiOptions::instance()->getOption("options.ui.account.privacy.show").toBool()) 
+
+	if (!PsiOptions::instance()->getOption("options.ui.account.privacy.show").toBool())
 		tab_main->removeTab(tab_main->indexOf(tab_privacy));
-	
+
 	if (!PsiOptions::instance()->getOption("options.ui.account.proxy.show").toBool()) {
 		lb_proxy->hide();
 		pc->hide();
@@ -302,12 +316,9 @@ void AccountModifyDlg::init()
 		lb_port->hide();
 		le_port->hide();
 	}
-	
-	if (!PsiOptions::instance()->getOption("options.ui.account.keepalive").toBool()) 
+
+	if (!PsiOptions::instance()->getOption("options.ui.account.keepalive").toBool())
 		ck_keepAlive->hide();
-	
-	if (!PsiOptions::instance()->getOption("options.ui.account.legacy-ssl-probe").toBool()) 
-		ck_legacy_ssl_probe->hide();
 
 	if (!PsiOptions::instance()->getOption("options.ui.account.security.show").toBool()) {
 		lb_plain->hide();
@@ -317,16 +328,16 @@ void AccountModifyDlg::init()
 		cb_security_level->hide();
 	}
 
-	if (!PsiOptions::instance()->getOption("options.ui.account.security.show").toBool() && !PsiOptions::instance()->getOption("options.ui.account.legacy-ssl-probe").toBool() && !PsiOptions::instance()->getOption("options.ui.account.keepalive").toBool() && !PsiOptions::instance()->getOption("options.ui.account.manual-host").toBool() && !PsiOptions::instance()->getOption("options.ui.account.proxy.show").toBool()) {
+	if (!PsiOptions::instance()->getOption("options.ui.account.security.show").toBool() && !PsiOptions::instance()->getOption("options.ui.account.keepalive").toBool() && !PsiOptions::instance()->getOption("options.ui.account.manual-host").toBool() && !PsiOptions::instance()->getOption("options.ui.account.proxy.show").toBool()) {
 		tab_main->removeTab(tab_main->indexOf(tab_connection));
 	}
-	
+
 	if (!PsiOptions::instance()->getOption("options.ui.account.resource").toBool()) {
 		cb_resource->hide();
 		lb_resource->hide();
 		le_resource->hide();
 	}
-	
+
 	if (!PsiOptions::instance()->getOption("options.ui.account.custom-authid").toBool()) {
 		ck_custom_auth->hide();
 		lb_authid->hide();
@@ -334,13 +345,13 @@ void AccountModifyDlg::init()
 		lb_realm->hide();
 		le_realm->hide();
 	}
-	
+
 	if (!PsiOptions::instance()->getOption("options.ui.account.priority").toBool()) {
 		lb_priority->hide();
 		cb_priority->hide();
 		sb_priority->hide();
 	}
-	
+
 	if (!PsiOptions::instance()->getOption("options.ui.account.data-proxy").toBool()) {
 		lb_dtProxy->hide();
 		le_dtProxy->hide();
@@ -349,7 +360,7 @@ void AccountModifyDlg::init()
 	if (!PsiOptions::instance()->getOption("options.ui.account.resource").toBool() && !PsiOptions::instance()->getOption("options.ui.account.priority").toBool() && !PsiOptions::instance()->getOption("options.ui.account.data-proxy").toBool()) {
 		tab_main->removeTab(tab_main->indexOf(tab_misc));
 	}
-	
+
 	resize(minimumSizeHint());
 }
 
@@ -429,8 +440,6 @@ void AccountModifyDlg::hostToggled(bool on)
 	lb_host->setEnabled(on);
 	le_port->setEnabled(on);
 	lb_port->setEnabled(on);
-	ck_legacy_ssl_probe->setEnabled(!on);
-	ck_legacy_ssl_probe->setChecked(on ? false : acc.legacy_ssl_probe);
 	if (!on && cb_ssl->currentIndex() == cb_ssl->findData(UserAccount::SSL_Legacy)) {
 		cb_ssl->setCurrentIndex(cb_ssl->findData(UserAccount::SSL_Auto));
 	}
@@ -478,6 +487,21 @@ void AccountModifyDlg::detailsChangePW()
 	}
 }
 
+void AccountModifyDlg::removeStunHost()
+{
+	// Don't remove no host
+	if (!cb_stunHost->currentIndex()) {
+		return;
+	}
+
+	QString host = cb_stunHost->currentText();
+	int item = cb_stunHost->findText(host);
+	if (item > -1) {
+		cb_stunHost->removeItem(item);
+	}
+	cb_stunHost->setCurrentIndex(0);
+}
+
 void AccountModifyDlg::save()
 {
 	/*if(pa && le_name->text().isEmpty()) {
@@ -491,7 +515,7 @@ void AccountModifyDlg::save()
 			QMessageBox::information(this, tr("Error"), tr("<i>Username</i> is invalid."));
 		}
 		else {
-			QMessageBox::information(this, tr("Error"), tr("<i>Jabber ID</i> must be specified in the format <i>user@host</i>."));
+			QMessageBox::information(this, tr("Error"), tr("<i>XMPP Address</i> must be specified in the format <i>user@host</i>."));
 		}
 		return;
 	}
@@ -525,8 +549,6 @@ void AccountModifyDlg::save()
 	acc.port = le_port->text().toInt();
 
 	acc.req_mutual_auth = ck_req_mutual->isChecked();
-	if (!ck_host->isChecked())
-		acc.legacy_ssl_probe = ck_legacy_ssl_probe->isChecked();
 	acc.security_level = cb_security_level->itemData(cb_security_level->currentIndex()).toInt();
 
 	acc.opt_automatic_resource = (cb_resource->currentIndex() == 1);
@@ -547,8 +569,15 @@ void AccountModifyDlg::save()
 	acc.opt_keepAlive = ck_keepAlive->isChecked();
 	acc.ibbOnly = ck_ibbOnly->isChecked();
 	acc.dtProxy = le_dtProxy->text();
-	acc.stunHost = le_stunHost->text();
-	acc.stunPort = le_stunPort->text().toInt();
+	acc.stunHost = cb_stunHost->currentIndex() ? cb_stunHost->currentText().trimmed() : "";
+	acc.stunHosts.clear();
+	// first item is no host
+	for (int i = 1; i < cb_stunHost->count(); i++) {
+		acc.stunHosts << cb_stunHost->itemText(i);
+	}
+	if (acc.stunHosts.indexOf(acc.stunHost) == -1) {
+		acc.stunHosts << acc.stunHost;
+	}
 	acc.stunUser = le_stunUser->text();
 	acc.stunPass = le_stunPass->text();
 
@@ -561,15 +590,17 @@ void AccountModifyDlg::save()
 
 		if (pa->isActive()) {
 			QMessageBox messageBox(QMessageBox::Information, tr("Warning"),
-			                       tr("This account is currently active, so certain changes may not take effect until the next login."),
-			                       QMessageBox::NoButton, this);
+								   tr("This account is currently active, so certain changes may not take effect until the next login."),
+								   QMessageBox::NoButton, this);
 			QPushButton* cancel = messageBox.addButton(tr("Reconnect &Later"), QMessageBox::RejectRole);
 			QPushButton* reconnect = messageBox.addButton(tr("Reconnect &Now"), QMessageBox::AcceptRole);
 			messageBox.setDefaultButton(reconnect);
 			messageBox.exec();
 			Q_UNUSED(cancel);
 			if (messageBox.clickedButton() == reconnect) {
-				pa->reconnectOnce();
+				XMPP::Status status = pa->status();
+				pa->setStatus(XMPP::Status::Offline);
+				pa->setStatus(status);
 			}
 		}
 		pa->reconfigureFTManager();
@@ -592,11 +623,10 @@ void AccountModifyDlg::addBlockClicked()
 		return;
 
 	bool ok;
-	QString input = QInputDialog::getText(NULL, tr("Block contact"), tr("Enter the Jabber ID of the contact to block:"), QLineEdit::Normal, "", &ok);
+	QString input = QInputDialog::getText(NULL, tr("Block contact"), tr("Enter the XMPP Address of the contact to block:"), QLineEdit::Normal, "", &ok);
 	Jid jid(input);
 	if (ok && !jid.isEmpty()) {
-		privacyModel.list().insertItem(0,PrivacyListItem::blockItem(jid.full()));
-		privacyModel.reset();
+		privacyModel.insertItem(0, PrivacyListItem::blockItem(jid.full()));
 		pa->privacyManager()->changeList(privacyModel.list());
 	}
 }
