@@ -304,7 +304,7 @@ void ChatEdit::keyPressEvent(QKeyEvent *e)
 		e->ignore();
 	else if(e->key() == Qt::Key_Return && 
 	       ((e->modifiers() & Qt::ControlModifier) 
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
 	       || (e->modifiers() & Qt::AltModifier) 
 #endif
 	       ))
@@ -323,7 +323,7 @@ void ChatEdit::keyPressEvent(QKeyEvent *e)
 		e->ignore();
 	else if((e->key() == Qt::Key_PageUp || e->key() == Qt::Key_PageDown) && (e->modifiers() & Qt::ControlModifier))
 		e->ignore(); */
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	else if (e->key() == Qt::Key_QuoteLeft && e->modifiers() == Qt::ControlModifier) {
 		e->ignore();
 	}
