@@ -122,7 +122,7 @@ void UserAccount::reset()
 	tog_self = false;
 	customAuth = false;
 	req_mutual_auth = false;
-	legacy_ssl_probe = true;
+	legacy_ssl_probe = false;
 	security_level = QCA::SL_None;
 	ssl = SSL_Auto;
 	jid = "";
@@ -131,12 +131,12 @@ void UserAccount::reset()
 	port = 5222;
 	opt_host = false;
 	host = "";
-	ibbOnly = false;
 	opt_automatic_resource = false;
 	priority_dep_on_status = true;
 	ignore_global_actions = false;
-	resource = "Psi+";
+	resource = ApplicationInfo::name();
 	priority = 55;
+	ibbOnly = false;
 	opt_keepAlive = true;
 	allow_plain = XMPP::ClientStream::AllowPlainOverTLS;
 	opt_compress = true;
@@ -154,7 +154,29 @@ void UserAccount::reset()
 	proxy_user = "";
 	proxy_pass = "";
 
-	stunPort = 3478;
+	stunHosts.clear();
+	stunHosts << "stun.jabber.ru:5249"
+			  << "stun.habahaba.im"
+			  << "stun.ekiga.net"
+			  << "provserver.televolution.net"
+			  << "stun1.voiceeclipse.net"
+			  << "stun.callwithus.com"
+			  << "stun.counterpath.net"
+			  << "stun.endigovoip.com"
+			  << "stun.ideasip.com"
+			  << "stun.internetcalls.com"
+			  << "stun.noc.ams-ix.net"
+			  << "stun.phonepower.com"
+			  << "stun.phoneserve.com"
+			  << "stun.rnktel.com"
+			  << "stun.softjoys.com"
+			  << "stun.sipgate.net"
+			  << "stun.sipgate.net:10000"
+			  << "stun.stunprotocol.org"
+			  << "stun.voipbuster.com"
+			  << "stun.voxgratia.org";
+
+	stunHost = stunHosts[0];
 
 	keybind.clear();
 
@@ -189,7 +211,7 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 	opt_log = o->getOption(base + ".log").toBool();
 	opt_reconn = o->getOption(base + ".reconn").toBool();
 	opt_ignoreSSLWarnings = o->getOption(base + ".ignore-SSL-warnings").toBool();
-	
+
 	// FIX-ME: See FS#771
 	if (o->getChildOptionNames().contains(base + ".connect-after-sleep")) {
 		opt_connectAfterSleep = o->getOption(base + ".connect-after-sleep").toBool();
@@ -215,10 +237,10 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 		opt_pass = true;
 		pass = decodePassword(tmp, jid);
 	}
-	
+
 	opt_host = o->getOption(base + ".use-host").toBool();
 	security_level = o->getOption(base + ".security-level").toInt();
-	
+
 	tmp = o->getOption(base + ".ssl").toString();
 	if (tmp == "no") {
 		ssl = SSL_No;
@@ -231,10 +253,10 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 	} else {
 		ssl = SSL_Yes;
 	}
-	
+
 	host = o->getOption(base + ".host").toString();
 	port = o->getOption(base + ".port").toInt();
-	
+
 	resource = o->getOption(base + ".resource").toString();
 	priority = o->getOption(base + ".priority").toInt();
 
@@ -273,9 +295,9 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 	} else if (tmp == "over encryped") {
 		allow_plain = XMPP::ClientStream::AllowPlainOverTLS;
 	} else {
-		allow_plain = XMPP::ClientStream::NoAllowPlain;		
+		allow_plain = XMPP::ClientStream::NoAllowPlain;
 	}
-	
+
 	QStringList rosterCache = o->getChildOptionNames(base + ".roster-cache", true, true);
 	foreach(QString rbase, rosterCache) {
 		RosterItem ri;
@@ -298,7 +320,7 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 		gd.rank = o->getOption(sbase + ".rank").toInt();
 		groupState.insert(k.toString(), gd);
 	}
-	
+
 	proxyID = o->getOption(base + ".proxy-id").toString();
 
 	keybind.fromOptions(o, base + ".pgp-key-bindings");
@@ -307,15 +329,14 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 	ibbOnly = o->getOption(base + ".ibb-only").toBool();
 
 
-	if (allSetOptions.contains(base + ".stun-host")) {
-		stunHost = o->getOption(base + ".stun-host").toString();
+	if (allSetOptions.contains(base + ".stun-hosts")) {
+		stunHosts = o->getOption(base + ".stun-hosts").toStringList();
+		if (allSetOptions.contains(base + ".stun-host")) {
+			stunHost = o->getOption(base + ".stun-host").toString();
+		}
 	}
-	if (allSetOptions.contains(base + ".stun-port")) {
-		int tmpPort = o->getOption(base + ".stun-port").toInt();
-		// a few days in the 0.13-dev development cycle the code set
-		// 0 as port when first adding this option. Ignore 0 for now
-		// and use default
-		if (tmpPort != 0) stunPort = tmpPort;
+	else if (!o->getOption(base + ".stun-host").toString().isEmpty()) {
+		stunHost = o->getOption(base + ".stun-host").toString();
 	}
 	if (allSetOptions.contains(base + ".stun-username")) {
 		stunUser = o->getOption(base + ".stun-username").toString();
@@ -410,7 +431,7 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
 		default:
 			qFatal("unknown allow_plain enum value in UserAccount::toOptions");
 	}
-	
+
 	int idx = 0;
 	foreach(RosterItem ri, roster) {
 		QString rbase = base + ".roster-cache.a" + QString::number(idx++);
@@ -420,7 +441,7 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
 		o->setOption(rbase + ".ask", ri.ask());
 		o->setOption(rbase + ".groups", ri.groups());
 	}
-	
+
 	// now we check for redundant entries
 	QStringList groupList;
 	QSet<QString> removeList;
@@ -460,8 +481,8 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
 	o->setOption(base + ".bytestreams-proxy", dtProxy.full());
 	o->setOption(base + ".ibb-only", ibbOnly);
 
+	o->setOption(base + ".stun-hosts", stunHosts);
 	o->setOption(base + ".stun-host", stunHost);
-	o->setOption(base + ".stun-port", QString::number(stunPort));
 	o->setOption(base + ".stun-username", stunUser);
 	o->setOption(base + ".stun-password", stunPass);
 
@@ -504,7 +525,7 @@ void UserAccount::fromXml(const QDomElement &a)
 	readBoolAttribute(a, "plain", &opt_plain);
 	allow_plain = (opt_plain ? XMPP::ClientStream::AllowPlain : XMPP::ClientStream::NoAllowPlain);
 	readNumEntry(a, "allow-plain", (int*) &allow_plain);
-	
+
 	// Will be overwritten if there is a new option
 	bool opt_ssl = true;
 	readBoolAttribute(a, "ssl", &opt_ssl);
@@ -791,15 +812,15 @@ bool OptionsMigration::fromFile(const QString &fname)
 			accMigration[i].proxyID = proxyMigration[accMigration[i].proxy_index-1].id;
 		}
 	}
-	
-	
-	
+
+
+
 	PsiOptions::instance()->setOption("options.ui.contactlist.show.offline-contacts", true);
 	PsiOptions::instance()->setOption("options.ui.contactlist.show.away-contacts", true);
 	PsiOptions::instance()->setOption("options.ui.contactlist.show.hidden-contacts-group", true);
 	PsiOptions::instance()->setOption("options.ui.contactlist.show.agent-contacts", true);
 	PsiOptions::instance()->setOption("options.ui.contactlist.show.self-contact", true);
-		
+
 	for (int i=0; i < accMigration.size(); i++) {
 		if (!accMigration[i].opt_enabled) continue;
 		PsiOptions::instance()->setOption("options.ui.contactlist.show.offline-contacts", accMigration[i].tog_offline);
@@ -810,7 +831,7 @@ bool OptionsMigration::fromFile(const QString &fname)
 		break;
 	}
 
-	
+
 	QDomElement p = findSubTag(base, "preferences", &found);
 	if(found) {
 		bool found;
@@ -838,7 +859,7 @@ bool OptionsMigration::fromFile(const QString &fname)
 					migrateStringEntry(sorting, "contact", "options.ui.contactlist.contact-sort-style");
 					migrateStringEntry(sorting, "group", "options.ui.contactlist.group-sort-style");
 					migrateStringEntry(sorting, "account", "options.ui.contactlist.account-sort-style");
-					
+
 					/* FIXME
 					readEntry(sorting, "contact", &name);
 					if ( name == "alpha" )
@@ -909,7 +930,7 @@ bool OptionsMigration::fromFile(const QString &fname)
 				migrateBoolEntry(tag, "autoCopy", "options.ui.automatically-copy-selected-text");
 				migrateBoolEntry(tag, "useCaps", "options.service-discovery.enable-entity-capabilities");
 				migrateBoolEntry(tag, "rc", "options.external-control.adhoc-remote-control.enable");
-				
+
 				// Migrating for soft return option
 				bool found;
 				findSubTag(tag, "chatSoftReturn", &found);
@@ -917,9 +938,9 @@ bool OptionsMigration::fromFile(const QString &fname)
 					bool soft;
 					readBoolEntry(tag, "chatSoftReturn", &soft);
 					QVariantList vl;
-					if (soft) 
+					if (soft)
 						vl << qVariantFromValue(QKeySequence(Qt::Key_Enter)) << qVariantFromValue(QKeySequence(Qt::Key_Return));
-					else 
+					else
 						vl << qVariantFromValue(QKeySequence(Qt::Key_Enter+Qt::CTRL)) << qVariantFromValue(QKeySequence(Qt::CTRL+Qt::Key_Return));
 					PsiOptions::instance()->setOption("options.shortcuts.chat.send",vl);
 				}
@@ -1018,7 +1039,7 @@ bool OptionsMigration::fromFile(const QString &fname)
 				lateMigrationData.sp.clear();
 				for(QDomNode n = tag.firstChild(); !n.isNull(); n = n.nextSibling()) {
 					StatusPreset preset(n.toElement());
-					if (!preset.name().isEmpty()) 
+					if (!preset.name().isEmpty())
 						lateMigrationData.sp[preset.name()] = preset;
 				}
 			}
@@ -1346,8 +1367,8 @@ void OptionsMigration::lateMigration()
 {
 	foreach(QString opt, PsiOptions::instance()->allOptionNames()) {
 		if (opt.startsWith("options.status.presets.") ||
-		    opt.startsWith("options.iconsets.service-status.") ||
-		    opt.startsWith("options.iconsets.custom-status."))
+			opt.startsWith("options.iconsets.service-status.") ||
+			opt.startsWith("options.iconsets.custom-status."))
 		{
 			return;
 		}
