@@ -19,6 +19,7 @@
 #include <QMessageBox>
 #include <QDebug>
 #include <QTimer>
+#include <QClipboard>
 
 #include "psicon.h"
 #include "psiaccount.h"
@@ -27,6 +28,7 @@
 #include "psiiconset.h"
 #include "iconwidget.h"
 #include "fancylabel.h"
+#include "textutil.h"
 #include "msgmle.h"
 #include "messageview.h"
 #include "iconselect.h"
@@ -141,7 +143,7 @@ public slots:
 			dlg_->appendSysMsg("No version information available.");
 			return;
 		}
-		dlg_->appendSysMsg(Qt::escape(QString("Version response: N: %2 V: %3 OS: %4")
+		dlg_->appendSysMsg(TextUtil::escape(QString("Version response: N: %2 V: %3 OS: %4")
 			.arg(version->name(), version->version(), version->os())));
 	};
 
@@ -159,7 +161,7 @@ public slots:
 				.arg(idle->time().toString()));
 		} else {
 			dlg_->appendSysMsg(QString("Last activity at %1 (%2)")
-				.arg(idle->time().toString(), Qt::escape(idle->status())));
+				.arg(idle->time().toString(), TextUtil::escape(idle->status())));
 		}
 	}
 
@@ -221,6 +223,10 @@ void PsiChatDlg::initUi()
 		updateAutojidIcon();
 		connect(act_autojid, SIGNAL(triggered()), SLOT(doSwitchJidMode()));
 		le_autojid->addAction(act_autojid);
+
+		QAction *act_copy_user_jid = new QAction(tr("Copy user JID"), this);
+		le_autojid->addAction(act_copy_user_jid);
+		connect(act_copy_user_jid, SIGNAL(triggered()), SLOT(copyUserJid()));
 	}
 
 	ui_.lb_ident->setAccount(account());
@@ -235,7 +241,7 @@ void PsiChatDlg::initUi()
 	connect(ui_.mle, SIGNAL(textEditCreated(QTextEdit*)), SLOT(chatEditCreated()));
 	chatEditCreated();
 
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	connect(chatView(), SIGNAL(selectionChanged()), SLOT(logSelectionChanged()));
 #endif
 
@@ -425,6 +431,11 @@ void PsiChatDlg::updateContactAdding(PsiContact* c)
 	}
 }
 
+void PsiChatDlg::copyUserJid()
+{
+	QApplication::clipboard()->setText(jid().bare());
+}
+
 void PsiChatDlg::updateContactAdding(const Jid &j)
 {
 	if (realJid().compare(j, false)) {
@@ -552,7 +563,7 @@ void PsiChatDlg::activated()
 			winHeader_->setVisible(!border);
 		setWindowBorder(border);
 		setMargins();
-#if defined(Q_WS_MAC) || defined(Q_WS_HAIKU)
+#if defined(Q_OS_MAC) || defined(Q_WS_HAIKU)
 		//
 #else
 		bringToFront(true);
@@ -641,7 +652,7 @@ void PsiChatDlg::updateJidWidget(const QList<UserListItem*> &ul, int status, boo
 					setJid(new_auto_jid);
 					if (old_jid != new_auto_jid) {
 						if (autoSelectContact_ && (status != XMPP::Status::Offline || !new_auto_jid.resource().isEmpty())) {
-							appendSysMsg(tr("Contact has been switched: %1").arg(JIDUtil::toString(new_auto_jid, true)));
+							appendSysMsg(tr("Contact has been switched: %1").arg(TextUtil::escape(JIDUtil::toString(new_auto_jid, true))));
 						}
 					}
 				}
@@ -776,12 +787,6 @@ void PsiChatDlg::updatePGP()
 {
 	if (account()->hasPGP()) {
 		act_pgp_->setEnabled(true);
-		if(PsiOptions::instance()->getOption("options.pgp.auto-start").toBool()) {
-			UserListItem *item = account()->findFirstRelevant(jid());
-			if(item && !item->publicKeyID().isEmpty()) {
-				setPGPEnabled(true);
-			}
-		}
 	}
 	else {
 		act_pgp_->setChecked(false);
@@ -789,9 +794,8 @@ void PsiChatDlg::updatePGP()
 	}
 
 	ui_.tb_pgp->setVisible(account()->hasPGP() &&
-	                       !smallChat_ &&
-	                       !PsiOptions::instance()->getOption("options.ui.chat.central-toolbar").toBool());
-
+						   !smallChat_ &&
+						   !PsiOptions::instance()->getOption("options.ui.chat.central-toolbar").toBool());
 	ui_.log->setEncryptionEnabled(isEncryptionEnabled());
 }
 
@@ -903,7 +907,7 @@ void PsiChatDlg::doSend() {
 	if (mCmdSite_.isActive()) {
 		QString str = chatEdit()->toPlainText();
 		if (!mCmdManager_.processCommand(str)) {
-			appendSysMsg(tr("Error: Can not parse command: ") + Qt::escape(str));
+			appendSysMsg(tr("Error: Can not parse command: ") + TextUtil::escape(str));
 		}
 	} else {
 		ChatDlg::doSend();
