@@ -35,6 +35,7 @@ static const QString slimGroupsOptionPath = "options.ui.look.contactlist.use-sli
 static const QString outlinedGroupsOptionPath = "options.ui.look.contactlist.use-outlined-group-headings";
 static const QString contactListBackgroundOptionPath = "options.ui.look.colors.contactlist.background";
 static const QString showStatusMessagesOptionPath = "options.ui.contactlist.status-messages.show";
+static const QString statusSingleOptionPath = "options.ui.contactlist.status-messages.single-line";
 static const QString showClientIconsPath = "options.ui.contactlist.show-client-icons";
 static const QString showMoodIconsPath = "options.ui.contactlist.show-mood-icons";
 static const QString showGeolocIconsPath = "options.ui.contactlist.show-geolocation-icons";
@@ -47,7 +48,6 @@ static const QString useDefaultAvatarPath = "options.ui.contactlist.avatars.use-
 static const QString avatarAtLeftOptionPath = "options.ui.contactlist.avatars.avatars-at-left";
 static const QString showStatusIconsPath = "options.ui.contactlist.show-status-icons";
 static const QString statusIconsOverAvatarsPath = "options.ui.contactlist.status-icon-over-avatar";
-static const QString statusSingleOptionPath = "options.ui.contactlist.status-messages.single-line";
 static const QString statusIconsetOptionPath = "options.iconsets.status";
 static const QString allClientsOptionPath = "options.ui.contactlist.show-all-client-icons";
 static const QString enableGroupsOptionPath = "options.ui.contactlist.enable-groups";
@@ -70,6 +70,7 @@ PsiContactListViewDelegate::PsiContactListViewDelegate(ContactListView* parent)
 	optionChanged(contactListFontOptionPath);
 	optionChanged(contactListBackgroundOptionPath);
 	optionChanged(showStatusMessagesOptionPath);
+	optionChanged(statusSingleOptionPath);
 	optionChanged(showClientIconsPath);
 	optionChanged(showMoodIconsPath);
 	optionChanged(showGeolocIconsPath);
@@ -82,7 +83,6 @@ PsiContactListViewDelegate::PsiContactListViewDelegate(ContactListView* parent)
 	optionChanged(avatarAtLeftOptionPath);
 	optionChanged(showStatusIconsPath);
 	optionChanged(statusIconsOverAvatarsPath);
-	optionChanged(statusSingleOptionPath);
 	optionChanged(allClientsOptionPath);
 	optionChanged(enableGroupsOptionPath);
 }
@@ -96,7 +96,7 @@ PsiContactListViewDelegate::~PsiContactListViewDelegate()
 int PsiContactListViewDelegate::avatarSize() const
 {
 	return showAvatars_ ?
-		qMax(avatarSize_ + 2, rowHeight) : rowHeight;
+		qMax(avatarSize_ + 2, rowHeight_) : rowHeight_;
 }
 
 QPixmap PsiContactListViewDelegate::statusPixmap(const QModelIndex& index) const
@@ -178,9 +178,9 @@ QSize PsiContactListViewDelegate::sizeHint(const QStyleOptionViewItem& /*option*
 			if(!statusSingle_ || !showStatusMessages_)
 				return QSize(16, avatarSize());
 			else
-				return QSize(16, qMax(avatarSize(), rowHeight*3/2));
+				return QSize(16, qMax(avatarSize(), rowHeight_*3/2));
 		} else {
-			return QSize(16, rowHeight);
+			return QSize(16, rowHeight_);
 		}
 	}
 
@@ -207,7 +207,7 @@ void PsiContactListViewDelegate::drawContact(QPainter* painter, const QStyleOpti
 			avatarRect.translate(-1,1);
 			r.setRight(avatarRect.left() - 3);
 		}
-		int row = (statusSingle_ && showStatusMessages_) ? rowHeight*3/2 : rowHeight;
+		int row = (statusSingle_ && showStatusMessages_) ? rowHeight_*3/2 : rowHeight_;
 		int h = (size - row)/2;
 		if(h > 0) {
 			r.setTop(r.top() + h);
@@ -280,7 +280,7 @@ void PsiContactListViewDelegate::drawContact(QPainter* painter, const QStyleOpti
 			drawText(painter, o, txtRect, text, index);
 			QString statusMsg = statusText(index);
 			palette.setColor(QPalette::Text, ColorOpt::instance()->color("options.ui.look.colors.contactlist.status-messages"));
-			o.palette = palette;               
+			o.palette = palette;
 			txtRect.moveTopRight(txtRect.bottomRight());
 			txtRect.setHeight(r.height() - txtRect.height());
 			o.font.setPointSize(qMax(o.font.pointSize()-2, 7));
@@ -293,6 +293,7 @@ void PsiContactListViewDelegate::drawContact(QPainter* painter, const QStyleOpti
 	else {
 		if(showStatusMessages_ && statusSingle_)
 			r.setHeight(r.height()*2/3);
+
 		drawText(painter, o, r, text, index);
 	}
 
@@ -507,7 +508,7 @@ void PsiContactListViewDelegate::optionChanged(const QString& option)
 		font_ = new QFont();
 		font_->fromString(PsiOptions::instance()->getOption(contactListFontOptionPath).toString());
 		fontMetrics_ = new QFontMetrics(*font_);
-		rowHeight = qMax(fontMetrics_->height()+2, statusIconSize_+2);
+		rowHeight_ = qMax(fontMetrics_->height()+2, statusIconSize_+2);
 		contactList()->viewport()->update();
 	}
 	else if (option == contactListBackgroundOptionPath) {
@@ -568,10 +569,6 @@ void PsiContactListViewDelegate::optionChanged(const QString& option)
 		statusIconsOverAvatars_ = PsiOptions::instance()->getOption(statusIconsOverAvatarsPath).toBool();
 		contactList()->viewport()->update();
 	}
-	else if(option == statusSingleOptionPath) {
-		statusSingle_ = !PsiOptions::instance()->getOption(statusSingleOptionPath).toBool();
-		contactList()->viewport()->update();
-	}
 	else if(option == slimGroupsOptionPath) {
 		slimGroup_ = PsiOptions::instance()->getOption(slimGroupsOptionPath).toBool();
 		contactList()->viewport()->update();
@@ -580,6 +577,10 @@ void PsiContactListViewDelegate::optionChanged(const QString& option)
 		outlinedGroup_ = PsiOptions::instance()->getOption(outlinedGroupsOptionPath).toBool();
 		contactList()->viewport()->update();
 	}
+	else if(option == statusSingleOptionPath) {
+		statusSingle_ = !PsiOptions::instance()->getOption(statusSingleOptionPath).toBool();
+		contactList()->viewport()->update();
+	}
 	else if(option == allClientsOptionPath) {
 		allClients_= PsiOptions::instance()->getOption(allClientsOptionPath).toBool();
 		contactList()->viewport()->update();
@@ -593,7 +594,7 @@ void PsiContactListViewDelegate::optionChanged(const QString& option)
 void PsiContactListViewDelegate::rosterIconsSizeChanged(int size)
 {
 	statusIconSize_ = size;
-	rowHeight = qMax(fontMetrics_->height()+2, statusIconSize_+2);
+	rowHeight_ = qMax(fontMetrics_->height()+2, statusIconSize_+2);
 	contactList()->viewport()->update();
 }
 
