@@ -22,7 +22,9 @@
 #include <QPixmap>
 #include <QList>
 #include <QtCrypto>
-#include <QTextDocument> // for Qt::escape()
+#include <QTextDocument> // for TextUtil::escape()
+#include <QBuffer>
+#include <QUrl>
 
 #include "userlist.h"
 #include "avatars.h"
@@ -750,7 +752,7 @@ QString UserListItem::makeTip(bool trim, bool doLinkify) const
 QString UserListItem::makeBareTip(bool trim, bool doLinkify) const
 {
 	// NOTE: If you add something to the tooltip,
-	// you most probably want to wrap it with Qt::escape()
+	// you most probably want to wrap it with TextUtil::escape()
 
 	QString str;
 	int s = PsiIconset::instance()->system().iconSize();
@@ -778,7 +780,7 @@ QString UserListItem::makeBareTip(bool trim, bool doLinkify) const
 	str += "<td>";
 
 	if (useAvatar) {
-		str += QString("<icon name=\"avatars/%1\">").arg(isPrivate() ? Qt::escape(jid().full()) : jid().bare());
+		str += QString("<icon name=\"avatars/%1\">").arg(isPrivate() ? TextUtil::escape(jid().full()) : jid().bare());
 		str += "</td><td width=\"10\"></td>";
 		str += "<td>";
 	}
@@ -786,9 +788,9 @@ QString UserListItem::makeBareTip(bool trim, bool doLinkify) const
 	QString nick = JIDUtil::nickOrJid(name(), jid().full());
 	if (!mucItem) {
 		if(jid().full() != nick)
-			str += QString("<div style='white-space:pre'>%1 &lt;%2&gt;</div>").arg(Qt::escape(nick)).arg(Qt::escape(JIDUtil::toString(jid(),true)));
+			str += QString("<div style='white-space:pre'>%1 &lt;%2&gt;</div>").arg(TextUtil::escape(nick)).arg(TextUtil::escape(JIDUtil::toString(jid(),true)));
 		else
-			str += QString("<div style='white-space:pre'>%1</div>").arg(Qt::escape(nick));
+			str += QString("<div style='white-space:pre'>%1</div>").arg(TextUtil::escape(nick));
 	}
 
 	// subscription
@@ -802,7 +804,7 @@ QString UserListItem::makeBareTip(bool trim, bool doLinkify) const
 	if (!mood().isNull()) {
 		str += QString("<div style='white-space:pre'><%1=\"mood/%2\"> ").arg(imgTag).arg(mood().typeValue()) + QObject::tr("Mood") + ": " + mood().typeText();
 		if (!mood().text().isEmpty())
-			str += QString(" (") + Qt::escape(mood().text()) + QString(")");
+			str += QString(" (") + TextUtil::escape(mood().text()) + QString(")");
 		str += "</div>";
 	}
 
@@ -817,22 +819,22 @@ QString UserListItem::makeBareTip(bool trim, bool doLinkify) const
 			str += QString(" - ") + activity().specificTypeText();
 		}
 		if (!activity().text().isEmpty())
-			str += QString(" (") + Qt::escape(activity().text()) + QString(")");
+			str += QString(" (") + TextUtil::escape(activity().text()) + QString(")");
 		str += "</div>";
 	}
 
 	// User Tune
 	if (!tune().isEmpty())
-		str += QString("<div style='white-space:pre'><%1=\"%2\"> ").arg(imgTag).arg("psi/notification_roster_tune") + QObject::tr("Listening to") + ": " + Qt::escape(tune()) + "</div>";
+		str += QString("<div style='white-space:pre'><%1=\"%2\"> ").arg(imgTag).arg("psi/notification_roster_tune") + QObject::tr("Listening to") + ": " + TextUtil::escape(tune()) + "</div>";
 
 	// User Physical Location
 	//if (!physicalLocation().isNull())
-	//	str += QString("<div style='white-space:pre'>") + QObject::tr("Location") + ": " + Qt::escape(physicalLocation().toString()) + "</div>";
+	//	str += QString("<div style='white-space:pre'>") + QObject::tr("Location") + ": " + TextUtil::escape(physicalLocation().toString()) + "</div>";
 
 	// User Geolocation
 	if (!geoLocation().isNull() && PsiOptions::instance()->getOption("options.ui.contactlist.tooltip.geolocation").toBool())
 		str += QString("<div style='white-space:pre'><table cellspacing=\"0\"><tr><td><%1=\"%2\"> </td><td><div>%3</div></td></tr></table></div>") \
-		.arg(imgTag).arg("system/geolocation").arg(Qt::escape(geoLocation().toString().trimmed()));
+		.arg(imgTag).arg("system/geolocation").arg(TextUtil::escape(geoLocation().toString().trimmed()));
 
 	// resources
 	if(!userResourceList().isEmpty()) {
@@ -848,33 +850,27 @@ QString UserListItem::makeBareTip(bool trim, bool doLinkify) const
 			else
 				name = QObject::tr("[blank]");
 
-			int status = makeSTATUS(r.status());
-			QString istr = "status/offline";
-			if(status == STATUS_ONLINE)
-				istr = "status/online";
-			else if(status == STATUS_AWAY)
-				istr = "status/away";
-			else if(status == STATUS_XA)
-				istr = "status/xa";
-			else if(status == STATUS_DND)
-				istr = "status/dnd";
-			else if(status == STATUS_CHAT)
-				istr = "status/chat";
-			else if(status == STATUS_INVISIBLE)
-				istr = "status/invisible"; //this shouldn't happen
-
 			QString secstr;
 			if(isSecure(r.name()) && PsiOptions::instance()->getOption("options.ui.contactlist.tooltip.pgp").toBool())
 				secstr += QString(" <%1=\"psi/cryptoYes\">").arg(imgTag);
 			QString hr;
 			if (!mucItem)
 				hr = "<hr/>";
-			if(r.status().mucItem().jid().isEmpty())
-				str += hr + QString("<div style='white-space:pre'><%1=\"%2\"> ").arg(imgTag).arg(istr) + QString("<b>%1</b> ").arg(Qt::escape(name)) \
-				+ QString("(%1)").arg(r.priority()) + secstr + "</div>";
-			else
-				str += hr +  QString("<div style='white-space:pre'><%1=\"%2\"> ").arg(imgTag).arg(istr) + QString("<b>%1</b> ").arg(Qt::escape(name)) \
-				+ QString("(%1) &lt;%2&gt;").arg(r.priority()).arg(JIDUtil::toString(r.status().mucItem().jid(),true)) + secstr + "</div>";
+			str += hr + "<div style='white-space:pre'>";
+
+			PsiIcon *statusIcon = PsiIconset::instance()->statusPtr(jid(), makeSTATUS(r.status()));
+			if (statusIcon) {
+				QByteArray imageArray;
+				QBuffer buff(&imageArray);
+				statusIcon->image().save(&buff, "png");
+				QString imgBase64(QUrl::toPercentEncoding(imageArray.toBase64()));
+				str += QString("<img src=\"data:image/png;base64,%1\" alt=\"img\"/>").arg(imgBase64);
+			}
+
+			str += QString(" <b>%1</b> ").arg(TextUtil::escape(name)) + QString("(%1)").arg(r.priority());
+			if (!r.status().mucItem().jid().isEmpty())
+				str += QString(" &lt;%1&gt;").arg(TextUtil::escape(JIDUtil::toString(r.status().mucItem().jid(),true)));
+			str += secstr + "</div>";
 
 			if(!r.publicKeyID().isEmpty() && PsiOptions::instance()->getOption("options.ui.contactlist.tooltip.pgp").toBool()) {
 				int v = r.pgpVerifyStatus();
@@ -902,10 +898,11 @@ QString UserListItem::makeBareTip(bool trim, bool doLinkify) const
 				QString ver = r.versionString();
 				if(trim)
 					ver = dot_truncate(ver, 80);
-				ver = Qt::escape(ver);
+				ver = TextUtil::escape(ver);
 				str += QString("<div class='layer1'><%1=\"%2\"> ").arg(imgTag).arg("clients/" + findClient(r.clientName().toLower())) + QObject::tr("Using") + QString(": %3").arg(ver) + "</div>";
 			}
 
+
 			// Entity Time
 			if (r.timezoneOffset().hasValue()) {
 				QDateTime dt = QDateTime::currentDateTime().toUTC().addSecs(r.timezoneOffset().value()*60);
@@ -970,10 +967,10 @@ QString UserListItem::makeBareTip(bool trim, bool doLinkify) const
 		// presence error
 		if(!v_perr.isEmpty()) {
 			QStringList err = v_perr.split('\n');
-			str += QString("<div style='white-space:pre'>") + QObject::tr("Presence Error") + QString(": %1").arg(Qt::escape(err[0])) + "</div>";
+			str += QString("<div style='white-space:pre'>") + QObject::tr("Presence Error") + QString(": %1").arg(TextUtil::escape(err[0])) + "</div>";
 			err.pop_front();
 			foreach (QString line, err)
-				str += "<div>" + line + "</div>";
+				str += "<div>" + Qt::escape(line) + "</div>";
 		}
 
 		// status message
